# ola-mundo-pack

Description. 
The package ola-mundo-pack is used to:
	- discar / retorna Olá mundo
	

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install ola-mundo-pack

```bash
pip install ola-mundo-pack
```

## Author
Jefferson

## License
[MIT](https://choosealicense.com/licenses/mit/)